@@ -31,6 +31,11 @@ from logzero import logger
 from chaosreliably import RELIABLY_HOST, STREAM_LOG, get_session
 from chaosreliably.activities.pauses import reset as reset_activity_pause
 from chaosreliably.controls import capture, find_extension_by_name, global_lock
+from chaosreliably.controls.vendors import (
+    apply_vendors,
+    register_vendors,
+    unregister_vendors,
+)
 
 __all__ = ["configure_control"]
 init_failed = threading.Event()
@@ -61,6 +66,8 @@ class ReliablyHandler(RunEventHandler):  # type: ignore
         self.paused = False
         self.check_for_user_state = None  # type: Optional[threading.Thread]
 
+        register_vendors()
+
     def _check(
         self,
         org_id: str,
@@ -231,6 +238,15 @@ class ReliablyHandler(RunEventHandler):  # type: ignore
                 ),
             )
             self.check_for_user_state.start()
+
+            apply_vendors(
+                "started",
+                experiment=experiment,
+                execution_url=url,
+                configuration=configuration,
+                secrets=secrets,
+            )
+
         except Exception as ex:
             init_failed.set()
             set_plan_status(
@@ -245,12 +261,23 @@ class ReliablyHandler(RunEventHandler):  # type: ignore
             self.check_for_user_state = None
 
         with global_lock:
-            log = STREAM_LOG.getvalue()
-
             self.current_activities = []
 
             try:
+                apply_vendors(
+                    "finished",
+                    journal=journal,
+                    configuration=self.configuration,
+                    secrets=self.secrets,
+                )
+
+                unregister_vendors()
+
                 if not init_failed.is_set():
+                    logger.info("Finished Reliably execution. Bye!")
+
+                    log = STREAM_LOG.getvalue()
+
                     complete_run(
                         self.org_id,
                         self.exp_id,
@@ -297,8 +324,6 @@ class ReliablyHandler(RunEventHandler):  # type: ignore
 
                 init_failed.clear()
 
-            logger.info("Finished Reliably execution. Bye!")
-
     def start_hypothesis_before(self, experiment: Experiment) -> None:
         with self.check_lock:
             self.current_activities = experiment.get(
